==> kdiff-0.8.4.tgz: kdiff-0.8.4/kdiff/main.cpp <==

/******************************************************************************
**         File: $RCSfile$
**
**  Description:
**
**      Created: $Date$
**
**      Changes: $Revision$
**   $Log$ 
**
** Distribution: $Name$ 
******************************************************************************/

/*-----------------------------------------------------------------------------
-- PRIVATE INCLUDE FILE DECLARATIONS
-----------------------------------------------------------------------------*/
#include "config.h"
#include "kdiffTopLevel.h"
#include "kdiff.h"

/*-----------------------------------------------------------------------------
-- SYSTEM INCLUDE FILE DECLARATIONS
-----------------------------------------------------------------------------*/
#include <kapp.h>

/*-----------------------------------------------------------------------------
-- DEFINITIONS
-----------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------
-- TYPE DEFINITIONS
-----------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------
-- GLOBAL VARIABLES
-----------------------------------------------------------------------------*/
int main(int argc, char **argv)
{
	KApplication *kdiffAppl = new KApplication(argc, argv, APPNAME);

	KdiffTopLevel *toplevel = new KdiffTopLevel(kdiffAppl, (const char *) APPNAME);

	toplevel->setCaption((const char *) APPNAME);
	toplevel->show();
	toplevel->resize(640, 480);

	return kdiffAppl->exec();

}

==> kdiff-0.83.tgz: kdiff-0.83/kdiff/main.cpp <==
/******************************************************************************
**         File: $RCSfile$
**
**  Description:
**
**      Created: $Date$
**
**      Changes: $Revision$
**   $Log$ 
**
** Distribution: $Name$ 
******************************************************************************/   

/*-----------------------------------------------------------------------------
-- PRIVATE INCLUDE FILE DECLARATIONS
-----------------------------------------------------------------------------*/
#include "config.h"
#include "kdiffTopLevel.h"
#include "kdiff.h"

/*-----------------------------------------------------------------------------
-- SYSTEM INCLUDE FILE DECLARATIONS
-----------------------------------------------------------------------------*/
#include <kapp.h>

/*-----------------------------------------------------------------------------
-- DEFINITIONS
-----------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------
-- TYPE DEFINITIONS
-----------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------
-- GLOBAL VARIABLES
-----------------------------------------------------------------------------*/
int main( int argc, char **argv )
{
  KApplication  *kdiffAppl = new KApplication( argc, argv, APPNAME );
  KLocale       *klocal = new KLocale();
  
  KdiffTopLevel *toplevel = new KdiffTopLevel( kdiffAppl, klocal,(const char*)APPNAME );

  toplevel->setCaption( (const char*)APPNAME );
  toplevel->show();
  toplevel->resize( 640, 480 );

  return kdiffAppl->exec();

}
